package org.drools.reteoo;

import static org.junit.Assert.assertEquals;

import org.drools.reteoo.model.Person;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.kie.api.KieBase;
import org.kie.api.KieServices;
import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.rule.QueryResults;

/**
 * Test to verify correct functionality of queries
 * with RETEOO vs. PHREAK.
 */
public class QueryTest {

    private static final long LOOPS = 100;

    private KieSession ksession;

    private Person petr, pavel, tomas, michaela, magda, monika;

    @Before
    public void prepareKieSession() throws Exception {
        KieServices ks = KieServices.Factory.get();
        KieBase kbase = ks.getKieClasspathContainer().getKieBase("queriesKBase");
        ksession = kbase.newKieSession();

        this.insertFacts();
    }

    @After
    public void disposeSession() {
        if (this.ksession != null) {
            this.ksession.dispose();
        }
    }

    private void insertFacts() {

        petr = new Person("Petr", "canoe", 25);
        pavel = new Person("Pavel", "basketball", 27);
        tomas = new Person("Tomas", "kendo", 23);
        michaela = new Person("Michaela", "films", 20);
        magda = new Person("Magda", "dogs", 17);
        monika = new Person("Monika", "voleyball", 30);

        ksession.insert(petr);
        ksession.insert(pavel);
        ksession.insert(tomas);
        ksession.insert(michaela);
        ksession.insert(magda);
        ksession.insert(monika);
    }

    @Test
    public void testForAllInQuery() {
        QueryResults results = ksession.getQueryResults("ifAllPersonsAreOlderReturnThem", 1);

        assertEquals(results.size(), 6);

        QueryResults results2 = ksession.getQueryResults("ifAllPersonsAreOlderReturnThem", 17);

        assertEquals(results2.size(), 0);
    }
}
